@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Amazon.py 12868 2021-04-28 20:10:26Z Lavender $
+# $Id: Amazon.py 12895 2021-05-13 08:35:36Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-04-29 04:10:26 +0800 (週四, 29 四月 2021) $
-# $Revision: 12868 $
+# $Date: 2021-05-13 16:35:36 +0800 (Thu, 13 May 2021) $
+# $Revision: 12895 $
 
 import boto3
 
@@ -30,11 +30,11 @@ class SES(object):
 
     def getIdentityNotificationAttributes(self, email):
         result = self.connection.get_identity_notification_attributes(Identities=[email,])
-        values = result.get("NotificationAttributes", {})
+        values = result.get("NotificationAttributes", {}).get(email, {})
         return values
 
     def setIdentityNotificationTopic(self, notificationType, identity, topic):
-        result = ses.set_identity_notification_topic(
+        result = self.connection.set_identity_notification_topic(
             Identity=identity,
             NotificationType=notificationType,
             SnsTopic=topic
