@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12980 2021-06-16 13:47:53Z Lavender $
+# $Id: views.py 13004 2021-06-23 12:25:44Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-06-16 21:47:53 +0800 (週三, 16 六月 2021) $
-# $Revision: 12980 $
+# $Date: 2021-06-23 20:25:44 +0800 (Wed, 23 Jun 2021) $
+# $Revision: 13004 $
 
 import base64
 from datetime import datetime
@@ -294,7 +294,10 @@ def mail(request):
                 if (_k.startswith('attachmentContent')) or (
                     _k.startswith('attachmentName')) or (
                     _k.startswith('attachmentType')):
-                    _d = unquote(_d.decode())
+                    if _k.startswith('attachmentContent'):
+                        _d = base64.b64decode(unquote(_d.decode()).encode()) 
+                    else:
+                        _d = unquote(_d.decode())
                     attachDict[_k] = _d
 
             for aId in attachmentIds:
@@ -333,14 +336,14 @@ def mail(request):
         else:
             return sendMail(newsletter)
     except CreateMailException as e:
-        logger.debug('[createMail]_FAILED: %s' % getComment(e))
+        logger.error('[createMail]_FAILED: %s' % getComment(e))
         return e.getWithDict()
     except Exception as e:
-        logger.debug('[createMail]_FAILED: %s' % getComment(e))
+        logger.error('[createMail]_FAILED: %s' % getComment(e))
         _e = CreateMailException(_unicode(e))
         return _e.getWithDict()
     finally:
-        logger.debug('[createMail]_END:')
+        logger.error('[createMail]_END:')
 
 @staff_member_required
 @view('GroupStatistics.html')
