@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: StatisticsHandler.py 13129 2021-07-30 05:11:59Z Casey $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (Fri, 07 Jun 2019) $
-# $Revision: 11616 $
+# $Author: Casey $
+# $Date: 2021-07-30 13:11:59 +0800 (Fri, 30 Jul 2021) $
+# $Revision: 13129 $
 
 from datetime import timedelta, datetime
 
@@ -36,6 +36,20 @@ STATUS_DICT = dict(ContactMailingStatus.STATUS_CHOICES)
 STATUS_NAMES = STATUS_DICT.values()
 STATUS_CODE = STATUS_DICT.keys()
 
+_STAUS_VALUES = [
+    STATUS_DICT[ContactMailingStatus.SENT],
+    STATUS_DICT[ContactMailingStatus.ERROR],
+    STATUS_DICT[ContactMailingStatus.INVALID],
+    STATUS_DICT[ContactMailingStatus.OPENED],
+    STATUS_DICT[ContactMailingStatus.OPENED_ON_SITE],
+    STATUS_DICT[ContactMailingStatus.LINK_OPENED],
+    STATUS_DICT[ContactMailingStatus.UNSUBSCRIPTION],
+    STATUS_DICT[ContactMailingStatus.BOUNCED],
+    STATUS_DICT[ContactMailingStatus.COMPLAINT],
+    STATUS_DICT[ContactMailingStatus.REJECTED],
+    STATUS_DICT[ContactMailingStatus.SENT_TEST]
+]
+
 from django.db import connection
 from django.conf import settings
 # check if strftime function is in current mysql
@@ -70,6 +84,13 @@ if settings.DATABASE_ENGINE == 'mysql':
                 """
         )
 
+def getStatusName():
+    _STATUS_NAMES = []
+    for i in _STAUS_VALUES:
+        _STATUS_NAMES.append(str(i))
+
+    return _STATUS_NAMES
+    
 def getDateRange(startDate, endDate):
     """
     Get range of dates.
@@ -769,9 +790,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     del tmp
 
 
-    _STATUS_NAMES = []
-    for i in STATUS_NAMES:
-        _STATUS_NAMES.append(str(i))
+    _STATUS_NAMES = getStatusName()
 
     response = {
         'context': {
@@ -847,9 +866,7 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
 
         rates.append((d, value))
 
-    _STATUS_NAMES = []
-    for i in STATUS_NAMES:
-        _STATUS_NAMES.append(str(i))
+    _STATUS_NAMES = getStatusName()
 
     response = {
         'context': dict(rates),
